summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmxmlparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmxmlparser.h')
-rw-r--r--kpovmodeler/pmxmlparser.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kpovmodeler/pmxmlparser.h b/kpovmodeler/pmxmlparser.h
index d33ff434..2ff8f351 100644
--- a/kpovmodeler/pmxmlparser.h
+++ b/kpovmodeler/pmxmlparser.h
@@ -70,10 +70,10 @@ private:
bool initDocument( );
/**
* Looks for child objects, parses them and appends them to the tqparent
* object. If tqparent is 0, all objects are appended to the result list.
*/
- void parseChildObjects( TQDomElement& e, PMObject* tqparent );
+ void parseChildObjects( TQDomElement& e, PMObject* parent );
TQDomDocument* m_pDoc;
int m_majorDocumentFormat;
@@ -70,10 +70,10 @@ private:
bool initDocument( );
/**
- * Looks for child objects, parses them and appends them to the tqparent
- * object. If tqparent is 0, all objects are appended to the result list.
+ * Looks for child objects, parses them and appends them to the parent
+ * object. If parent is 0, all objects are appended to the result list.
*/